@@ -68,6 +68,7 @@ public class saspy2j
    static String               uuid1     = null;
    static SASURI               uri       = null;
    static String               uriStr    = null;
+   static String               reconStr  = null;
    static boolean              reconnect = false;
 
    static org.omg.CORBA.StringHolder qualUserNameHolder = null;
@@ -162,6 +163,8 @@ public class saspy2j
             lrecl = Integer.parseInt(args[x + 1]);
          else if (args[x].equalsIgnoreCase("-logbufsz"))
             logsz = Integer.parseInt(args[x + 1]);
+         else if (args[x].equalsIgnoreCase("-uri"))
+             reconStr = args[x + 1];
          }
 
       iomhosts = iomhost.split(";");
@@ -214,7 +217,7 @@ public class saspy2j
          }
       else
          {
-         if (! spn)
+         if (! spn && uriStr == null)
             omrpw = inp.readLine();
          connect(false, false, false);
          }
@@ -234,7 +237,7 @@ public class saspy2j
                      {
                      flen = Long.valueOf(pgm.substring(0, idx));
                      pgm  = pgm.substring(idx + 13 + 33);
-               
+
                      bstr = null;
                      try
                         {
@@ -252,7 +255,7 @@ public class saspy2j
                         }
                      catch (GenericError e)
                         {}
-               
+
                      if (! (bstr == null))
                         {
                         while (flen > 0)
@@ -266,28 +269,14 @@ public class saspy2j
                                  bstr.Write(java.util.Arrays.copyOfRange(out, 0, slen));
                                  }
                               }
-                           catch (org.omg.CORBA.COMM_FAILURE e)
-                              {
-                              if (reconnect)
-                                 {
-                                 ods = true;
-                                 connect(true, true, false);
-                                 bstr = fileref.OpenBinaryStream(StreamOpenMode.StreamOpenModeForWriting);
-                                 bstr.Write(odsdata.value);
-                                 }
-                              else
-                                 {
-                                 String msg = "We failed in Submit\n"+e.getMessage();
-                                 errp.write(msg);
-                                 errp.flush();
-                                 System.out.print(msg);
-                                 e.printStackTrace();
-                                 throw new IOException();
-                                 }
-                              }
                            catch (Exception e)
                               {
-                              slen = 0; 
+                              String msg = "We failed in Submit\n"+e.getMessage();
+                              errp.write(msg);
+                              errp.flush();
+                              System.out.print(msg);
+                              e.printStackTrace();
+                              throw new IOException();
                               }
                            }
                         bstr.Close();
@@ -296,7 +285,7 @@ public class saspy2j
                   else if (eol.contains("DNLOAD"))
                      {
                      pgm  = pgm.substring(idx + 13 + 33);
-               
+
                      bstr = null;
                      try
                         {
@@ -333,28 +322,14 @@ public class saspy2j
                                  odsout.flush();
                                  }
                               }
-                           catch (org.omg.CORBA.COMM_FAILURE e)
-                              {
-                              if (reconnect)
-                                 {
-                                 ods = true;
-                                 connect(true, true, false);
-                                 bstr = fileref.OpenBinaryStream(StreamOpenMode.StreamOpenModeForReading);
-                                 bstr.Read(blen, odsdata);
-                                 }
-                              else
-                                 {
-                                 String msg = "We failed in Submit\n"+e.getMessage();
-                                 errp.write(msg);
-                                 errp.flush();
-                                 System.out.print(msg);
-                                 e.printStackTrace();
-                                 throw new IOException();
-                                 }
-                              }
                            catch (Exception e)
                               {
-                              slen = 0; 
+                              String msg = "We failed in Submit\n"+e.getMessage();
+                              errp.write(msg);
+                              errp.flush();
+                              System.out.print(msg);
+                              e.printStackTrace();
+                              throw new IOException();
                               }
                            }
                         bstr.Close();
@@ -392,9 +367,13 @@ public class saspy2j
                         {
                         cx.close();
                         errp.write("Succesfully disconnected. Be sure to have a valid network connection before submitting anything else.DISCONNECT");
+                        errp.write(uriStr+"END_DISCON");
                         }
                      else
+                        {
                         errp.write("This workspace server is not configured for reconnecting. Did not disconnect.DISCONNECT");
+                        errp.write("END_DISCON");
+                        }
 
                      errp.flush();
                      pgm = pgm.substring(idx + 13 + 33);
@@ -424,15 +403,15 @@ public class saspy2j
                               cx.close();
                               server     = (BridgeServer) Server.fromURI(uri);
                               ad         = server.getDomain();
-                    
+
                               if (appName != "")
                                  server.setServerName(appName.replace("\'", ""));
                               server.setOption(SASURI.applicationNameKey, "SASPy");
-                              
+
                               cxfConfig  = new ManualConnectionFactoryConfiguration(server);
                               cxfManager = new ConnectionFactoryManager();
                               cxf        = cxfManager.getFactory(cxfConfig);
-                              
+
                               if (spn)
                                  cx = cxf.getConnection(cred);
                               else
@@ -708,6 +687,13 @@ private static void connect(boolean recon, boolean ods, boolean zero) throws IOE
     VariableArray2dOfStringHolder infoPropertyNames  = new VariableArray2dOfStringHolder();
     VariableArray2dOfStringHolder infoPropertyValues = new VariableArray2dOfStringHolder();
 
+    if (reconStr != null)
+       {
+       uri      = SASURI.create(reconStr);
+       recon    = true;
+       reconStr = null;
+       }
+
     if (! zero)
        {
        if (recon)
@@ -719,11 +705,11 @@ private static void connect(boolean recon, boolean ods, boolean zero) throws IOE
              if (appName != "")
                 server.setServerName(appName.replace("\'", ""));
              server.setOption(SASURI.applicationNameKey, "SASPy");
-   
+
              cxfConfig  = new ManualConnectionFactoryConfiguration(server);
              cxfManager = new ConnectionFactoryManager();
              cxf        = cxfManager.getFactory(cxfConfig);
-   
+
              if (spn)
                 cx = cxf.getConnection(cred);
              else if (timeout > 0)
@@ -751,14 +737,14 @@ private static void connect(boolean recon, boolean ods, boolean zero) throws IOE
                 if (appName != "")
                    server.setServerName(appName.replace("\'", ""));
                 server.setOption(SASURI.applicationNameKey, "SASPy");
-   
+
                 if (spn)
                    server.setSecurityPackage(Server.SECURITY_PACKAGE_NEGOTIATE);
-   
+
                 cxfConfig  = new ManualConnectionFactoryConfiguration(server);
                 cxfManager = new ConnectionFactoryManager();
                 cxf        = cxfManager.getFactory(cxfConfig);
-   
+
                 if (spn)
                    {
                    cred = SecurityPackageCredential.getInstance();
