@@ -302,7 +302,7 @@ class SASSessionCOM(object):
         # Store flush result in running log
         self._log += result
 
-        if result.count('ERROR:') > 0:
+        if result.count('\nERROR:') > 0:
            warnings.warn("Noticed 'ERROR:' in LOG, you ought to take a look and see if there was a problem")
            self._sb.check_error_log = True
 
@@ -486,7 +486,16 @@ class SASSessionCOM(object):
             #   1. Swap \x0c for \n
             #   2. Change body class selector
             #   3. Increase font size
-            listing = self._getfile(self._gethtmlfn(), decode=True) \
+            lstf = self._getfile(self._gethtmlfn())
+            try:
+               lstf = lstf.decode()
+            except UnicodeDecodeError: # older SAS used session encoding instead of utf8 like newer SAS
+               try:
+                  lstf = lstf.decode(self.sascfg.encoding)
+               except UnicodeDecodeError:
+                  lstf = lstf.decode(errors='replace')
+
+            listing = lstf \
                 .replace(chr(12), chr(10)) \
                 .replace('<body class="c body">', '<body class="l body">') \
                 .replace('font-size: x-small;', 'font-size: normal;')
