@@ -709,7 +709,7 @@ class SASsessionHTTP():
       if jobid != None:
          self._log += logr.replace(chr(12), chr(10))
 
-      if logr.count('ERROR:') > 0:
+      if logr.count('\nERROR:') > 0:
          warnings.warn("Noticed 'ERROR:' in LOG, you ought to take a look and see if there was a problem")
          self._sb.check_error_log = True
 
@@ -1002,10 +1002,6 @@ class SASsessionHTTP():
          resp = req.read()
          conn.close()
 
-      if logd.count('ERROR:') > 0:
-         warnings.warn("Noticed 'ERROR:' in LOG, you ought to take a look and see if there was a problem")
-         self._sb.check_error_log = True
-
       return dict(LOG=logd, LST=lstd)
 
    def saslog(self):
@@ -1214,8 +1210,12 @@ class SASsessionHTTP():
       logf += ll['LOG']
       fd.close()
 
-      return {'Success' : True,
-              'LOG'     : logf}
+      if status > 299:
+         return {'Success' : False,
+                 'LOG'     : "Failure in upload. Status="+str(status)+"\nResponse="+str(resp.decode())}
+      else:
+         return {'Success' : True,
+                 'LOG'     : logf}
 
    def download(self, localfile: str, remotefile: str, overwrite: bool = True, **kwargs):
       """
@@ -1261,16 +1261,26 @@ class SASsessionHTTP():
       req = conn.getresponse()
       status = req.status
 
-      fd.write(req.read())
-      fd.flush()
+      if status > 299:
+         ret = {'Success' : False,
+                'LOG'     : "Failure in download. Status="+str(status)+"\nReason="+str(req.reason)}
+      else:
+         while not req.isclosed():
+            fd.write(req.read(1024*1024))
+         fd.flush()
+         ret = None
+
       fd.close()
       conn.close()
 
       ll = self.submit("filename _sp_updn;", 'text')
       logf += ll['LOG']
 
-      return {'Success' : True,
-              'LOG'     : logf}
+      if ret is None:
+         ret = {'Success' : True,
+                'LOG'     : logf}
+
+      return ret
 
    def _getbytelenF(self, x):
       return len(x.encode(self.sascfg.encoding))
@@ -1565,19 +1575,25 @@ class SASsessionHTTP():
       resp = req.read()
       conn.close()
 
-      js = json.loads(resp.decode(self.sascfg.encoding))
+      try:
+         js = json.loads(resp.decode(self.sascfg.encoding))
 
-      varlist = []
-      vartype = []
-      nvars = js.get('count')
-      lst = js.get('items')
-      for i in range(len(lst)):
-         varlist.append(lst[i].get('name'))
-         vartype.append(lst[i].get('type'))
+         varlist = []
+         vartype = []
+         nvars = js.get('count')
+         lst = js.get('items')
+         for i in range(len(lst)):
+            varlist.append(lst[i].get('name'))
+            vartype.append(lst[i].get('type'))
 
-      dvarlist = list(varlist)
-      for i in range(len(varlist)):
-         varlist[i] = varlist[i].replace("'", "''")
+         dvarlist = list(varlist)
+         for i in range(len(varlist)):
+            varlist[i] = varlist[i].replace("'", "''")
+      except Exception as e:
+         logger.error("Invalid output produced durring sasdata2dataframe step. Step failed.\
+         \nPrinting the error: {}\nPrinting the SASLOG as diagnostic\n{}\
+         \nPrinting the Status and Response as diagnostic\n{}\n{}".format(str(e), ll['LOG'], str(status), str(resp)))
+         return None
 
       topts = dict(dsopts)
       topts.pop('firstobs', None)
@@ -1592,10 +1608,15 @@ class SASsessionHTTP():
 
       ll = self.submit(code, "text")
 
-      l2 = ll['LOG'].rpartition("FMT_CATS=")
-      l2 = l2[2].partition("\n")
-      varcat = l2[2].split("\n", nvars)
-      del varcat[nvars]
+      try:
+         l2 = ll['LOG'].rpartition("FMT_CATS=")
+         l2 = l2[2].partition("\n")
+         varcat = l2[2].split("\n", nvars)
+         del varcat[nvars]
+      except Exception as e:
+         logger.error("Invalid output produced durring sasdata2dataframe step. Step failed.\
+         \nPrinting the error: {}\nPrinting the SASLOG as diagnostic\n{}".format(str(e), ll['LOG']))
+         return None
 
       code  = "proc delete data=work.sasdata2dataframe(memtype=view);run;\n"
       code += "data work.sasdata2dataframe / view=work.sasdata2dataframe; set "+tabname+self._sb._dsopts(dsopts)+";\nformat "
@@ -1730,19 +1751,25 @@ class SASsessionHTTP():
       resp = req.read()
       conn.close()
 
-      js = json.loads(resp.decode(self.sascfg.encoding))
+      try:
+         js = json.loads(resp.decode(self.sascfg.encoding))
 
-      varlist = []
-      vartype = []
-      nvars = js.get('count')
-      lst = js.get('items')
-      for i in range(len(lst)):
-         varlist.append(lst[i].get('name'))
-         vartype.append(lst[i].get('type'))
+         varlist = []
+         vartype = []
+         nvars = js.get('count')
+         lst = js.get('items')
+         for i in range(len(lst)):
+            varlist.append(lst[i].get('name'))
+            vartype.append(lst[i].get('type'))
 
-      dvarlist = list(varlist)
-      for i in range(len(varlist)):
-         varlist[i] = varlist[i].replace("'", "''")
+         dvarlist = list(varlist)
+         for i in range(len(varlist)):
+            varlist[i] = varlist[i].replace("'", "''")
+      except Exception as e:
+         logger.error("Invalid output produced durring sasdata2dataframe step. Step failed.\
+         \nPrinting the error: {}\nPrinting the SASLOG as diagnostic\n{}\
+         \nPrinting the Status and Response as diagnostic\n{}\n{}".format(str(e), ll['LOG'], str(status), str(resp)))
+         return None
 
       topts = dict(dsopts)
       topts.pop('firstobs', None)
@@ -1758,10 +1785,15 @@ class SASsessionHTTP():
 
       ll = self.submit(code, "text")
 
-      l2 = ll['LOG'].rpartition("FMT_CATS=")
-      l2 = l2[2].partition("\n")
-      varcat = l2[2].split("\n", nvars)
-      del varcat[nvars]
+      try:
+         l2 = ll['LOG'].rpartition("FMT_CATS=")
+         l2 = l2[2].partition("\n")
+         varcat = l2[2].split("\n", nvars)
+         del varcat[nvars]
+      except Exception as e:
+         logger.error("Invalid output produced durring sasdata2dataframe step. Step failed.\
+         \nPrinting the error: {}\nPrinting the SASLOG as diagnostic\n{}".format(str(e), ll['LOG']))
+         return None
 
       rdelim = "'"+'%02x' % ord(rowsep.encode(self.sascfg.encoding))+"'x"
       cdelim = "'"+'%02x' % ord(colsep.encode(self.sascfg.encoding))+"'x "
