@@ -372,13 +372,13 @@ Will use HTML5 for this SASsession.""")
                   logger.warning('Did not find key '+self.sascfg.authkey+' in authinfo file:'+pwf+'\n')
 
             while len(user) == 0:
-               user = self.sascfg._prompt("Please enter the IOM user id: ")
+               user = self.sascfg._prompt("Please enter the OMR user id: ")
                if user is None:
                   self.sockin.close()
                   self.sockout.close()
                   self.sockerr.close()
                   self.pid = None
-                  raise RuntimeError("No SAS IOM User id provided.")
+                  raise RuntimeError("No SAS OMR User id provided.")
 
       pgm    = self.sascfg.java
       parms  = [pgm]
@@ -532,14 +532,14 @@ Will use HTML5 for this SASsession.""")
       if not zero and not self.sascfg.reconuri:
          if not self.sascfg.sspi:
             while len(pw) == 0:
-               pw = self.sascfg._prompt("Please enter the password for IOM user "+self.sascfg.omruser+": ", pw=True)
+               pw = self.sascfg._prompt("Please enter the password for OMR user "+self.sascfg.omruser+": ", pw=True)
                if pw is None:
                   if os.name == 'nt':
                      self.pid.kill()
                   else:
                      os.kill(self.pid, signal.SIGKILL)
                   self.pid = None
-                  raise RuntimeError("No SAS IOM User password provided.")
+                  raise RuntimeError("No SAS OMR User password provided.")
             pw += '\n'
             self.stdin[0].send(pw.encode())
 
@@ -931,7 +931,6 @@ Will use HTML5 for this SASsession.""")
                     lst = b''
 
                  if len(lst) > 0:
-                    #print("LIST = \n"+lst)
                     lstf += lst
                  else:
                     sleep(0.1)
@@ -941,7 +940,6 @@ Will use HTML5 for this SASsession.""")
                        log = b''
 
                     if len(log) > 0:
-                       #print("LOG = \n"+log)
                        logf += log
                        if logf.count(logcodeo) >= 1:
                           bail = True
@@ -1007,7 +1005,7 @@ Will use HTML5 for this SASsession.""")
       lstd = lstf.replace(chr(12), chr(10)).replace('<body class="c body">',
                                                     '<body class="l body">').replace("font-size: x-small;",
                                                                                      "font-size:  normal;")
-      if logd.count('ERROR:') > 0:
+      if logd.count('\nERROR:') > 0:
          warnings.warn("Noticed 'ERROR:' in LOG, you ought to take a look and see if there was a problem")
          self._sb.check_error_log = True
 
@@ -1759,26 +1757,31 @@ Will use HTML5 for this SASsession.""")
 
       ll = self.submit(code, "text")
 
-      l2 = ll['LOG'].rpartition("LRECL= ")
-      l2 = l2[2].partition("\n")
-      lrecl = int(l2[0])
+      try:
+         l2 = ll['LOG'].rpartition("LRECL= ")
+         l2 = l2[2].partition("\n")
+         lrecl = int(l2[0])
 
-      l2 = l2[2].partition("VARNUMS= ")
-      l2 = l2[2].partition("\n")
-      nvars = int(l2[0])
+         l2 = l2[2].partition("VARNUMS= ")
+         l2 = l2[2].partition("\n")
+         nvars = int(l2[0])
 
-      l2 = l2[2].partition("\n")
-      varlist = l2[2].split("\n", nvars)
-      del varlist[nvars]
+         l2 = l2[2].partition("\n")
+         varlist = l2[2].split("\n", nvars)
+         del varlist[nvars]
 
-      dvarlist = list(varlist)
-      for i in range(len(varlist)):
-         varlist[i] = varlist[i].replace("'", "''")
+         dvarlist = list(varlist)
+         for i in range(len(varlist)):
+            varlist[i] = varlist[i].replace("'", "''")
 
-      l2 = l2[2].partition("VARTYPE=")
-      l2 = l2[2].partition("\n")
-      vartype = l2[2].split("\n", nvars)
-      del vartype[nvars]
+         l2 = l2[2].partition("VARTYPE=")
+         l2 = l2[2].partition("\n")
+         vartype = l2[2].split("\n", nvars)
+         del vartype[nvars]
+      except Exception as e:
+         logger.error("Invalid output produced durring sasdata2dataframe step. Step failed.\
+         \nPrinting the error: {}\nPrinting the SASLOG as diagnostic\n{}".format(str(e), ll['LOG']))
+         return None
 
       topts = dict(dsopts)
       topts.pop('firstobs', None)
@@ -1794,10 +1797,15 @@ Will use HTML5 for this SASsession.""")
 
       ll = self.submit(code, "text")
 
-      l2 = ll['LOG'].rpartition("FMT_CATS=")
-      l2 = l2[2].partition("\n")
-      varcat = l2[2].split("\n", nvars)
-      del varcat[nvars]
+      try:
+         l2 = ll['LOG'].rpartition("FMT_CATS=")
+         l2 = l2[2].partition("\n")
+         varcat = l2[2].split("\n", nvars)
+         del varcat[nvars]
+      except Exception as e:
+         logger.error("Invalid output produced durring sasdata2dataframe step. Step failed.\
+         \nPrinting the error: {}\nPrinting the SASLOG as diagnostic\n{}".format(str(e), ll['LOG']))
+         return None
 
       code = "data work.sasdata2dataframe / view=work.sasdata2dataframe; set "+tabname+self._sb._dsopts(dsopts)+";\nformat "
 
@@ -1870,12 +1878,10 @@ Will use HTML5 for this SASsession.""")
 
       if not local:
          try:
-
             sockout = _read_sock(io=self, rowsep=b'\n', encoding=self.sascfg.encoding,
                                  lstcodeo=lstcodeo.encode(), logcodeb=logcodeb)
 
             df = pd.read_csv(sockout, index_col=idx_col, encoding='utf8', engine=eng, dtype=dts, **kwargs)
-
          except:
             if os.name == 'nt':
                try:
@@ -1924,7 +1930,7 @@ Will use HTML5 for this SASsession.""")
 
          logd = logf.decode(errors='replace')
          self._log += logd.replace(chr(12), chr(10))
-         if logd.count('ERROR:') > 0:
+         if logd.count('\nERROR:') > 0:
             warnings.warn("Noticed 'ERROR:' in LOG, you ought to take a look and see if there was a problem")
             self._sb.check_error_log = True
 
@@ -1995,26 +2001,31 @@ Will use HTML5 for this SASsession.""")
 
       ll = self.submit(code, "text")
 
-      l2 = ll['LOG'].rpartition("LRECL= ")
-      l2 = l2[2].partition("\n")
-      lrecl = int(l2[0])
+      try:
+         l2 = ll['LOG'].rpartition("LRECL= ")
+         l2 = l2[2].partition("\n")
+         lrecl = int(l2[0])
 
-      l2 = l2[2].partition("VARNUMS= ")
-      l2 = l2[2].partition("\n")
-      nvars = int(l2[0])
+         l2 = l2[2].partition("VARNUMS= ")
+         l2 = l2[2].partition("\n")
+         nvars = int(l2[0])
 
-      l2 = l2[2].partition("\n")
-      varlist = l2[2].split("\n", nvars)
-      del varlist[nvars]
+         l2 = l2[2].partition("\n")
+         varlist = l2[2].split("\n", nvars)
+         del varlist[nvars]
 
-      dvarlist = list(varlist)
-      for i in range(len(varlist)):
-         varlist[i] = varlist[i].replace("'", "''")
+         dvarlist = list(varlist)
+         for i in range(len(varlist)):
+            varlist[i] = varlist[i].replace("'", "''")
 
-      l2 = l2[2].partition("VARTYPE=")
-      l2 = l2[2].partition("\n")
-      vartype = l2[2].split("\n", nvars)
-      del vartype[nvars]
+         l2 = l2[2].partition("VARTYPE=")
+         l2 = l2[2].partition("\n")
+         vartype = l2[2].split("\n", nvars)
+         del vartype[nvars]
+      except Exception as e:
+         logger.error("Invalid output produced durring sasdata2dataframe step. Step failed.\
+         \nPrinting the error: {}\nPrinting the SASLOG as diagnostic\n{}".format(str(e), ll['LOG']))
+         return None
 
       topts = dict(dsopts)
       topts.pop('firstobs', None)
@@ -2030,10 +2041,15 @@ Will use HTML5 for this SASsession.""")
 
       ll = self.submit(code, "text")
 
-      l2 = ll['LOG'].rpartition("FMT_CATS=")
-      l2 = l2[2].partition("\n")
-      varcat = l2[2].split("\n", nvars)
-      del varcat[nvars]
+      try:
+         l2 = ll['LOG'].rpartition("FMT_CATS=")
+         l2 = l2[2].partition("\n")
+         varcat = l2[2].split("\n", nvars)
+         del varcat[nvars]
+      except Exception as e:
+         logger.error("Invalid output produced durring sasdata2dataframe step. Step failed.\
+         \nPrinting the error: {}\nPrinting the SASLOG as diagnostic\n{}".format(str(e), ll['LOG']))
+         return None
 
       rdelim = "'"+'%02x' % ord(rowsep.encode(self.sascfg.encoding))+"'x"
       cdelim = "'"+'%02x' % ord(colsep.encode(self.sascfg.encoding))+"'x "
@@ -2111,14 +2127,12 @@ Will use HTML5 for this SASsession.""")
       #self.stdin[0].send(b'\n'+logcodei.encode()+b'\n'+b'tom says EOL='+logcodeb)
 
       try:
-
          sockout = _read_sock(io=self, method='DISK', rsep=(colsep+rowsep+'\n').encode(), rowsep=rowsep.encode(),
                               lstcodeo=lstcodeo.encode(), logcodeb=logcodeb)
 
          df = pd.read_csv(sockout, index_col=idx_col, engine=eng, header=None, names=dvarlist,
                           sep=colsep, lineterminator=rowsep, dtype=dts, na_values=miss,
                           encoding='utf-8', quoting=quoting, **kwargs)
-
       except:
          if os.name == 'nt':
             try:
@@ -2199,7 +2213,7 @@ class _read_sock(io.StringIO):
 
                   logd = self.logf.decode(errors='replace')
                   self._io._log += logd.replace(chr(12), chr(10))
-                  if logd.count('ERROR:') > 0:
+                  if logd.count('\nERROR:') > 0:
                      warnings.warn("Noticed 'ERROR:' in LOG, you ought to take a look and see if there was a problem")
                      self._io._sb.check_error_log = True
 
